cmd

package
v0.0.0-...-d4ea3c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 11, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Package cmd is our cobra/viper cli implementation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). This only needs to happen once to the rootCmd.

Types

This section is empty.

Jump to